PyXMake Developer Guide: PyXMake.VTL.stm_post Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.stm_post Namespace Reference

Post-processing build jobs on Jenkins2 using PyXMake. More...

## Functions
| main ()

## Detailed Description

Post-processing build jobs on Jenkins2 using PyXMake.

    Jenkins2 post-processing script.

    @note: Post-processing build jobs on Jenkins2 using PyXMake.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake, PyCODAC

    @change:
          -

    @author:
           - garb_ma                                              [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  03.04.2021

Notes/Changes
  - Added documentation // mg 03.04.2021

## Function Documentation

## ◆ main()

PyXMake.VTL.stm_post.main | ( |  | ) |

    Main function to execute the script.

Definition at line 43 of file stm_post.py.